% PDECOL - Solve one dimensional PDE's using ALGORITHM 540 PDECOL.
% 
% The types of PDE's that can be solved take the following form
% 
% u_t = f(t,x,u,u_x,u_xx)
% 
% With u a vector of NPDE unknown functions, u_t and u_x representing time
% and spacial derivatives respectfully.  Boundary conditions take the form
% of equations of the following form
% 
% b(u,u_x) = z(t)
% 
% and must be consistent with the initial conditions.  The user of the 
% routine must at minimum specify the following octave functions:
% 
% A function to evaluate f (defined above)
% A function to evaluate the derivative of b with respect to u
% " """""""" "" """""""" """ """""""""" "" " """" """"""" "" u_x
% " """""""" "" """""""" """ """""""""" "" z """" """"""" "" t
% A function to evaluate and return the initial conditions
% 
% This method in space is a finite element collocation method with piecewise 
% polynomials (B-Splines).  The time integration is performed using the method
% of lines with choices for several standard ordinary differential equations 
% solvers.  Many more details can be found in the original article:
% 
% Algorithm 540: PDECOL, General Collocation Software for Partial Differential Equations
% by N. K. Madsen, R. F. Sincovec
% ACM Transactions on Mathematical Software (TOMS), Volume 5 Issue 3 (September 1979)
% 
% Written by:
% -- 
% John L. Weatherwax                2005-04-27
% 
% email: wax@alum.mit.edu
% 
% Please send comments and especially bug reports to the
% above email address.
% 
%-----

% Parameter studies in the paper:
nTests = 8; 
kordv  = [ 3 3 4 4 5 5 6 6 ]; 
nintv  = [ 10 20 8 16 4 8 2 4 ]; 
epsv   = [ 3*10^(-5) 10^(-5) 10^(-6) 10^(-7) 10^(-6) 10^(-8) 10^(-6) 10^(-8) ]; 

% Parameter studies in the file EG2.f:
%kordv = [ 3 3 3 3 3 3 4 4 4 4 4 5 5 5 5 6 6 6 ]; 

nrms = zeros(1,nTests); 
for ti=1:nTests,
  if( 1 ) 
    [ U, opts ] = pdecol("F","DBDU_BNDRY","DBDUX_BNDRY","DZDT_BNDRY","UINIT", ...
			 'kord', kordv(ti), 'nint', nintv(ti), 'eps', epsv(ti), 'tgrid', [ 0 0.1 ] );
  else
    [ U, opts ] = pdecol( "F","DBDU_BNDRY","DBDUX_BNDRY","DZDT_BNDRY","UINIT",...
			  "dfdu", "DFDU_DERIVF","dfdux", "DFDUX_DERIVF", "dfduxx", "DFDUXX_DERIVF", 
                          "MF", 21, ...
			  'kord', kordv(ti), 'nint', nintv(ti), 'eps', epsv(ti), 'tgrid', [ 0 0.1 ] );
  end
  
  u_a = squeeze(U).'; 
  tGrid = opts.tGrid; 
  xbkpt = opts.xbkpt; 
  
  t_end = 0.1; 
  u_e = u_exact( xbkpt, t_end ); 
  nrms(ti) = norm( u_e - u_a ); 
  
  if( 1 ) 
    %close all; 
    ntouts = length(tGrid)-1; 
    h=figure; 
    plot( xbkpt, u_a, xbkpt, u_e ); grid;
  end
  %pause; 
end
